@@ -28,7 +28,7 @@ class Preprocessing:
         preprocessingConfig = config["preprocessing"]
 
         instance.targetChannels = preprocessingConfig["targetChannels"]
-        instance.stepsByType = preprocessingConfig["signals"]
+        instance.stepsByType = preprocessingConfig["stepsPerType"]
         instance.forceGapBetweenEvents = preprocessingConfig["forceGapBetweenEvents"]
 
         cls.instance = instance
@@ -252,7 +252,7 @@ class Preprocessing:
     #         labelSignalArray[(stageSignal & bitMaskInt) > 0] = 1
     #     elif labelName == "copy":
     #         sourceSignal = psgSignal.getFirstSignalByName(fc["channel"])
-    #         stepsByType = self.preprocessingConfig["signals"]
+    #         stepsByType = self.preprocessingConfig["stepsPerType"]
     #         sourceSignal.type = fc["type"] if "type" in fc else None
 
     #         if sourceSignal.type in stepsByType:
@@ -694,7 +694,7 @@ class Preprocessing:
                         self.parseSignalSteps(signal, processStep, psgSignal, signal)
                 elif type is not None:
                     self.logError(
-                        "Signaltype %s for signal %s has no preprocessing steps (defined in preprocessing.signals.[type])"
+                        "Signaltype %s for signal %s has no preprocessing steps (defined in preprocessing.stepsPerType.[type])"
                         % (signal.type, signal.name)
                     )
             else:
